/*
 * Copyright (C) 2010-2020 Alibaba Group Holding Limited
 */

#ifndef editor_ios_h
#define editor_ios_h
#include <stdint.h>
#include <functional>
#include "editor/editor_callback.h"
#include "common/svideo_export.h"
#include <string>
#include "editor/caption/caption.h"
#include "editor/pip/pip.h"
#include <list>
#include <memory>
#include <vector>
#include <map>

using namespace NS_SVIDEO;

class TransitionEffectStruct
{
public:
    int type{0};
    int64_t overlapDuration{0};
    int64_t orientation{0};
    int64_t direction{0};
    float lineWidth{0};
    int n{5};
    const char* filePath{nullptr};
    const char* paramsString{nullptr};
};


class FrameAniamtionParamStruct
{
public:

    //base

    int mScope = 0; //动画类型

    int mType = -1; //动画类型

    int mTargetId = -1; //动画节点

    bool mIsStream = false; //是否视频流


    int64_t mStartTime = -1000000; //毫秒

    int64_t mDuration = -1000000;  //毫秒

    int64_t mStartOff = -1000000;  //延迟毫秒

    int mInterpolator = -1;  //时间插值

    int    mFillBefore = -1;
    int    mFillAfter = -1;



    int mRepeatMode = -1; //重复

    bool mRepeatCount = -1; //重复次数

    int part_Mode = 0;//子动画执行模式
    float part_overlayRadio = 0; //子节点的重叠部分


    std::string mAnimationConfig = "";//动画参数额外配置








    //translate
    float mFromPointX = 0.5;

    float mFromPointY = 0.5;

    float mToPointX = 0.5;

    float mToPointY = 0.5;

    int mTranslateType = 0;



    //scale
    float mFromScale = 1;

    float mToScale = 1;

    bool mScaleAnchorEnable = false;

    float mScaleAnchorBaseScale = 1;

    float mScaleAnchorX = 0.5;

    float mScaleAnchorY = 0.5;

    //alpha
    float mAlpha = 1;

    float mFromAlpha = 1;

    float mToAlpha = 1;

    //rotation
    bool mClockwise = false;

    float mFromDegree = 0;

    float mRotateDegree = 0;

    float mRotateToDegree = 0;

    int mCenterCoordinateSys = 0;

    float mCenterX = 0.5;

    float mCenterY = 0.5;

    int64_t mDurationPerCircle = -1;

    //wipe
    int mDirection = -1;

    int mWipeMode = -1;



    //shader
    std::string mVertexFunctionStr = "";
    std::string mFragmentFunctionStr = "";

    //set
    int mSetMode = 0;
    std::vector<std::shared_ptr<FrameAniamtionParamStruct>> mSetList;
    int mSetListCount = 0;

    //custom
    std::map<std::string, float> uniformsMapper; //片段着色器unit

    int64_t nativeActionId = 0;


};


//enum EditorProcessMode
//{
//    PROCESS_MODE_PLAY,
//    PROCESS_MODE_COMPOSE
//};

/**
 返回句柄

 @return editor句柄
 */
SVIDEO_EXPORT extern long svideo_editor_create();

SVIDEO_EXPORT extern void svideo_editor_createLicenseParam(long handle, const char* bundleId, const char * platForm, const char *sdkVersion, const char *version);

/**
 初始化editor

 @param handle   句柄
 @param width    宽
 @param height   高
 @param glView   glView
 @param reportId reportId
 @return 0：成功 其他失败
 */
SVIDEO_EXPORT extern int svideo_editor_init(long handle, int width, int height, void *glView, int64_t reportId, int64_t logId, EditorCallback *cb);


/**
 设置view

 @param handle 句柄
 @param glView OpenGLView
 @return 0：成功 其他失败
 */
SVIDEO_EXPORT extern int svideo_editor_set_glView(long handle, void *glView);

/**
 设置渲染宽高

 @param handle 句柄
 @param width 宽高
 @param height
 @return 0：成功 其他失败
 */
SVIDEO_EXPORT extern int svideo_editor_set_display_size(long handle, int width, int height);

/**
 添加视频（同步）

 @param filePathPtr 资源路径
 @param startTime 视频开始时间
 @param duration 播放时长
 @param inDuration 入场时长
 @param outDuration 出场时长
 @param overlapDuration 重叠时长
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_add_video_element(long handle, const char* filePathPtr, int64_t startTime, int64_t duration, int64_t inDuration, int64_t outDuration, int64_t overlapDuration);

SVIDEO_EXPORT extern int svideo_editor_add_video_element(long handle, const char* filePathPtr, int64_t startTime, int64_t duration, TransitionEffectStruct effect);

SVIDEO_EXPORT extern int svideo_editor_add_image_element(long handle, const char* filePathPtr, int64_t duration, TransitionEffectStruct effect);

SVIDEO_EXPORT extern int svideo_editor_add_image_element(long handle, const char* filePathPtr, int64_t duration, int64_t inDuration, int64_t outDuration, int64_t overlapDuration);

SVIDEO_EXPORT extern int svideo_editor_update_stream_element(long handle, int id, int64_t streamStartTime, int64_t streamDuration);

SVIDEO_EXPORT extern int svideo_editor_update_transition(long handle, int id, const char* paramsString);

SVIDEO_EXPORT extern int svideo_editor_set_output_path(long handle, const char* path);
/**
 设置模式

 @param mode 0：播放  1：合成
 @return 返回值
 */
SVIDEO_EXPORT extern int svideo_editor_set_mode(long handle, int mode);

SVIDEO_EXPORT extern int svideo_editor_set_display_mode(long handle, int mode);

/**
 准备播放

 @return 返回结果
 */
SVIDEO_EXPORT extern int svideo_editor_prepare(long handle);

SVIDEO_EXPORT extern int svideo_editor_unPrepare(long handle);

/**
 开始播放

 @return 返回结果
 */
SVIDEO_EXPORT extern int svideo_editor_start(long handle);

SVIDEO_EXPORT extern int svideo_editor_pause(long handle);

SVIDEO_EXPORT extern int svideo_editor_resume(long handle);

SVIDEO_EXPORT extern int svideo_editor_stop(long handle);

SVIDEO_EXPORT extern int svideo_editor_draw(long handle, int64_t timeStamp);

SVIDEO_EXPORT extern int svideo_editor_draw_to_buffer(long handle, int64_t timeStamp,
        std::shared_ptr<uint8_t> &buf, uint32_t &bufWidth, uint32_t &bufHeight);

SVIDEO_EXPORT extern int svideo_editor_async_screen_capture(long handle, int64_t timeStamp, int64_t tolerance,
        const std::function<void(int64_t, const std::function<void(std::shared_ptr<uint8_t>&, uint32_t&, uint32_t&)> &)> &callback);

SVIDEO_EXPORT extern int svideo_editor_seek(long handle, int64_t timeStamp);

SVIDEO_EXPORT extern int64_t svideo_editor_get_duration(long handle);

SVIDEO_EXPORT extern int64_t svideo_editor_get_play_time(long handle);

SVIDEO_EXPORT extern int64_t svideo_editor_get_stream_duration(long handle);

SVIDEO_EXPORT extern int svideo_editor_get_mv_audio_streamID(long handle);

SVIDEO_EXPORT extern int64_t svideo_editor_get_stream_play_time(long handle);

SVIDEO_EXPORT extern int64_t svideo_editor_get_clip_startTime_at_index(long handle, int idx);

/**
 销毁

 @param handle 销毁
 */
SVIDEO_EXPORT extern void svideo_editor_release(long handle);

SVIDEO_EXPORT extern int svideo_editor_set_mix(long handle, const char* filePath, int weight, int64_t startTime, int64_t duration, int64_t streamStartTime, int64_t streamDuration);

SVIDEO_EXPORT extern int svideo_editor_remove_mix(long handle, int id);

SVIDEO_EXPORT extern int svideo_editor_set_mix_alpha(long handle, int id, int weight);

SVIDEO_EXPORT extern int svideo_editor_set_audio_denoise(long handle, int id, float param);

SVIDEO_EXPORT extern int svideo_editor_add_dub(long handle, const char* filePath, int weight, int64_t startTime, int64_t duration, int64_t streamStartTime, int64_t streamDuration);

SVIDEO_EXPORT extern int svideo_editor_remove_dub(long handle, int id);

SVIDEO_EXPORT extern int svideo_editor_set_volume(long handle, int volume);

SVIDEO_EXPORT extern int svideo_editor_set_fps(long handle, double fps);

/**
 @param sid  0=>brightness 1=>contrast 2=>saturation 3=>sharpness 4=>vignette
 */
SVIDEO_EXPORT extern int svideo_editor_set_vdieo_eq(long handle, int sid, int type, float value);

SVIDEO_EXPORT extern int svideo_editor_set_vdieo_horizontal_flip(long handle, int sid, bool flip);

SVIDEO_EXPORT extern int svideo_editor_audioEffect(long handle, int id, int type, float pitchRate);

SVIDEO_EXPORT extern int svideo_editor_removeAudioEffect(long handle, int id, int type);

SVIDEO_EXPORT extern int svideo_editor_set_audio_fade(long handle, int id, int shape, long duration, bool isFadeIn);

SVIDEO_EXPORT extern int svideo_editor_remove_audio_fade(long handle, int id, bool isFadeIn);

/**
 添加滤镜

 @param handle 句柄
 @param filePath 资源路径
 @return 添加结果
 */
SVIDEO_EXPORT extern int svideo_apply_filter(long handle, const char* filePath, int64_t startTime, int64_t duration);

/**
 添加特效滤镜

 @param handle 句柄
 @param filePath 资源路径
 @return 添加结果
 */
SVIDEO_EXPORT extern int svideo_apply_animation_filter(long handle, const char *filePath, int64_t startTime, int64_t duration, const char* paramsString);

SVIDEO_EXPORT extern int svideo_update_animation_filter(long handle, int vid, int64_t startTime, int64_t duration, const char* paramsString);

SVIDEO_EXPORT extern int svideo_delete_animation_filter(long handle, int vid);

SVIDEO_EXPORT extern int svideo_apply_blur_background_display(long handle, int streamId, float blurRadius, int64_t startTime, int64_t duration);

SVIDEO_EXPORT extern int svideo_delete_blur_background_display(long handle, int vid, int streamId);

SVIDEO_EXPORT extern int svideo_apply_running_displaymode(long handle, int streamId, int64_t startTime, int64_t duration, int policy = 0);

SVIDEO_EXPORT extern int svideo_delete_running_displaymode(long handle, int vid);

/**
 添加MV

 @param handle 句柄
 @param filePath 资源路径
 @param startTime 开始时间
 @param duration 持续时间
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_apply_mv(long handle, const char* filePath, int64_t startTime, int64_t duration);

/**
 检查剪同款授权

 @param handle 句柄
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_check_template(long handle);

/**
 设置速度

 @param handle 句柄
 @param rate 速率
 @param startTime 开始时间
 @param duration 持续时间
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_rate(long handle, float rate, int64_t startTime, int64_t duration, bool needOriginDuration);


/**
 设置反复播放

 @param handle 句柄
 @param times 播放次数
 @param startTime 开始时间
 @param duration 持续时间
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_repeat(long handle, int times, int64_t startTime, int64_t duration, bool needOriginDuration);

/**
 设置倒放

 @param handle 句柄
 @param startTime 开始时间
 @param duration 持续时间
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_invert(long handle);

/**
 变声
 @param handle 句柄
 @param id 流id
 @param startTime 开始时间
 @param duration 持续时间
 @param pitchRate 变声度 越小越粗
 */
SVIDEO_EXPORT extern int svideo_editor_pitch(long handle, int id, int64_t startTime, int64_t duration, int type, float pitchRate);

/**
 取消时间特效

 @param handle 句柄
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_reset_time_effect(long handle);

/**
 删除某一个时间特效

 @param handle 句柄
 @param vid 特效id
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_delete_time_effect(long handle, int vid);

/**
 取消mv

 @param handle 句柄
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_reset_mv(long handle);

/**
 取消mv音乐

 @param handle 句柄
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_reset_mv_audio(long handle);

/**
 获取编排层service状态

 @param handle 句柄
 @return 结果
 */
SVIDEO_EXPORT extern int svideo_editor_get_state(long handle);

/**
 取消配音

 @param handle 句柄
 @return 结果
 */
SVIDEO_EXPORT int svideo_editor_reset_mix(long handle);

/**
 取消变声

 @param handle 句柄
 @return 结果
 */
SVIDEO_EXPORT int svideo_editor_reset_pitch(long handle);

//视频底层背景颜色
//handle:NativeScreen句柄，由#init生成
//rgbColor 颜色值 由     unsigned long rgba = (((((a << 8) + r) << 8) + g) << 8) + b;生成
SVIDEO_EXPORT extern int svideo_editor_background_color(long handle, unsigned long rgbColor);

//切换特效
//handle:NativeScreen句柄，由#init生成
//path:特效资源文件所在路径
//return: 0 if sucessed
SVIDEO_EXPORT extern int svideo_editor_switch_eff(long handle, const char* path, int vid, int64_t startTime, int64_t duration);

/**
 动效滤镜

 @param handle 句柄
 @param path 资源路径
 @param vid vid
 @param startTime 开始时间
 @param duration 终止时间
 @return 0 if successed
 */
SVIDEO_EXPORT extern int svideo_editor_switch_animation_eff(long handle, const char *path, int vid, int64_t startTime, int64_t duration);

/**
添加帧动画
 */
SVIDEO_EXPORT extern  int svideo_editor_addFrameAniamtionParam(long handle, const FrameAniamtionParamStruct& param);


SVIDEO_EXPORT extern std::shared_ptr<FrameAnimationParam> svideo_editor_parseFrameAnimationParam(const  FrameAniamtionParamStruct& param);

/**
 */
SVIDEO_EXPORT extern int svideo_editor_remove_action(long handle, int vid, int actionId, int scope, bool isStream);


//添加一个静态水印
//handle:NativeScreen句柄，由#init生成
//vid:指定所添加的view id，注意vid是全局唯一的，由调用者维护
//c_path:指定所显示图片的文件路径，确认具有访问权限
//pos : x, y
//size : w, h
//rotate : r
//return: 0 if sucessed
SVIDEO_EXPORT extern int svideo_editor_add_img_view(long handle, const char* path,
        float x, float y, float w, float h, float r,
        int64_t startTime = 0, int64_t duration = 0, int viewType = 0);

//添加一个静态水印
//handle:NativeScreen句柄，由#init生成
//vid:指定所添加的view id，注意vid是全局唯一的，由调用者维护
//bmp:指定所显示图片
//pos : x, y
//size : w, h
//rotate : r
//return: 0 if sucessed
SVIDEO_EXPORT extern int svideo_editor_add_img_view(long handle, int width, int height,
        int widthStep, void* pdata, float x, float y,
        float w, float h, float r,
        int64_t startTime = 0, int64_t duration = 0,
        bool ifText = false, int viewType = 0);

//底层生成图片
SVIDEO_EXPORT extern int svideo_editor_add_text(long handle,
        const char* text,
        const char* fontName,
        bool isStroke,
        unsigned long textColor,
        unsigned long strokeColor,
        unsigned long backgroundColor,
        float w,
        float h,
        float r,
        float x,
        float y,
        int64_t startTime = 0, int64_t duration = 0, int64_t relativeTime = 0);

//添加一个动图view
//handle:NativeScreen句柄，由#init生成
//vid:指定所添加的view id，注意vid是全局唯一的，由调用者维护
//pos : x, y
//size : w, h
//rotate : r
//flip
//duration: 指定动图view存在时间，如果为0则全局存在，需手动调用接口删除，单位微妙
//return: 0 if sucessed
SVIDEO_EXPORT extern int svideo_editor_add_gif_view(long handle, const char* path,
        float x, float y, float w, float h,
        float rotate, bool flip,
        int64_t startTime = 0, int64_t duration = 0, bool isFont = false);

SVIDEO_EXPORT extern int svideo_add_gif_text_view(long handle,
        const char* path,
        float x,
        float y,
        float w,
        float h,
        float rotate,
        bool flip,
        int64_t startTime,
        int64_t duration,
        bool isFont,
        const char* text,
        const char* fontName,
        bool isStroke,
        unsigned long textColor,
        unsigned long strokeColor,
        unsigned long backgroundColor,
        float tw,
        float th,
        float tr,
        float tx,
        float ty,
        int64_t tStartTime,
        int64_t tDuration,
        int64_t relativeStartTime);

//暂时把某个view设置为invisible,注意该属性会在resume播放时自动恢复为visible
//handle:NativeScreen句柄，由#init生成
//vid:指定所添加的view id，注意vid是全局唯一的，由调用者维护
SVIDEO_EXPORT extern int svideo_editor_hide_view(long handle, int vid);

//把某个view设置为invisible
//handle:NativeScreen句柄，由#init生成
//vid:指定所添加的view id，注意vid是全局唯一的，由调用者维护
SVIDEO_EXPORT extern int svideo_editor_show_view(long handle, int vid);

//删除由vid指定的view
//handle:NativeScreen句柄，由#init生成
//vid:view id
SVIDEO_EXPORT extern int svideo_editor_delete_view(long handle, int vid, int viewType);

//设置位置
//handle:NativeScreen句柄，由#init生成
// vid: 操作目标
//x, y: position
SVIDEO_EXPORT extern int svideo_editor_set_view_pos(long handle, int vid, float x, float y);

//设置尺寸
//handle:NativeScreen句柄，由#init生成
// vid: 操作目标
//x, y: size
SVIDEO_EXPORT extern int svideo_editor_set_view_size(long handle, int vid, float size_x, float size_y);

//设置片尾水印
//handle:NativeScreen句柄，由#init生成
// path: 水印图片路径
// size: 图片尺寸
// pos: 图片位置，（0，0）标记为中心
// duration: 水印时间
SVIDEO_EXPORT extern int svideo_editor_set_tail(long handle, const char* path, float size_x,
        float size_y, float pos_x, float pos_y,
        long duration);

SVIDEO_EXPORT extern int svideo_editor_set_param(long handle, int fps, int bitrate, int gop, int encodeType,  int quality);

/**
 获取时间特效类型

 @param handle 句柄
 @return  TIME_EFFECT_NONE 0,
 TIME_EFFECT_SPEED 1,
 TIME_EFFECT_REPEAT 2,
 TIME_EFFECT_INVERT 3
 */
SVIDEO_EXPORT extern int svideo_editor_get_time_effect(long handle);

/**
 设置单路流最大缓存

 @param handle 句柄
 @param cache_size 缓存大小
 */
SVIDEO_EXPORT extern int svideo_editor_set_max_cache_size(long handle, int cache_size);

/**
 获取视频需要的最大缓存

 @param handle 句柄
 @param path 视频路径
 @return 缓存大小
 */
SVIDEO_EXPORT extern int svideo_editor_get_max_estimated_cache_size(long handle, const char* path);

/**
 * 向复杂字幕组添加一个字幕
 * @param vid 添加资源获取的资源id
 */
SVIDEO_EXPORT extern int svideo_add_rollCaption_itemView(long handle, int vid, float x, float y, float w, float h, float r, int displayWidth, int displayHeight, int64_t startTime,
        int64_t duration);
/**
 * 复杂字幕生效
 */


SVIDEO_EXPORT extern int svideo_apply_rollCaptionEffects(long handle);

/**
 * 清除复杂字幕
 */
SVIDEO_EXPORT extern int svideo_clear_rollCaptionEffects(long handle);

SVIDEO_EXPORT extern int svideo_add_caption(long handle, std::shared_ptr<NS_SVIDEO::Caption> caption);

SVIDEO_EXPORT int svideo_remove_caption(long handle, long caption);

SVIDEO_EXPORT extern int svideo_find_captions(long handle, long pts, std::list<std::shared_ptr<NS_SVIDEO::Caption> > &captionList);

SVIDEO_EXPORT extern int svideo_update_caption(long handle, long caption);

// MARK: - pip
SVIDEO_EXPORT extern int svideo_add_pip(long handle, const std::shared_ptr<NS_SVIDEO::Pip> &pip);
SVIDEO_EXPORT extern int svideo_update_pip(long handle, const std::shared_ptr<NS_SVIDEO::Pip> &pip);
SVIDEO_EXPORT extern int svideo_remove_pip(long handle, int streamId);


SVIDEO_EXPORT extern int svideo_apply_lut_filter(long handle, const char *filePath, float intensity, int64_t startTime, int64_t duration, int streamId = 1);



#endif /* editor_ios_hpp */
